"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.rule = void 0;
const path_1 = __importDefault(require("path"));
const util_1 = require("./util");
function create(context) {
    const filename = context.getFilename();
    if (path_1.default.basename(filename) !== 'package.json')
        return {};
    const { ignoredScripts = [] } = context.options[0] || {};
    return {
        AssignmentExpression(node) {
            const _node = node;
            const scripts = _node.right.properties.find(p => p.key.value === 'scripts');
            if (!scripts)
                return;
            const filteredScripts = scripts.value.properties.filter(node => !ignoredScripts.includes(node.key.value));
            if (filteredScripts.length === 0)
                return;
            filteredScripts.map(node => {
                util_1.extractGlobsFromString(node.value.value).forEach(glob => {
                    if (!util_1.isQuoted(glob)) {
                        context.report({
                            node,
                            message: `disallow unquoted glob: ${glob}`,
                        });
                    }
                });
            });
        },
    };
}
exports.rule = {
    meta: {
        type: 'problem',
        docs: {
            description: 'disallow unquoted glob pattern',
        },
        schema: [
            {
                type: 'object',
                properties: {
                    ignoredScripts: {
                        type: 'array',
                    },
                },
                additionalProperties: false,
            },
        ],
    },
    create,
};
